Options

Struct Options 

pub struct Options {
    pub heading_style: HeadingStyle,
    pub hr_style: HrStyle,
    pub br_style: BrStyle,
    pub link_style: LinkStyle,
    pub link_reference_style: LinkReferenceStyle,
    pub code_block_style: CodeBlockStyle,
    pub code_block_fence: CodeBlockFence,
    pub bullet_list_marker: BulletListMarker,
    pub ul_bullet_spacing: u8,
    pub ol_number_spacing: u8,
    pub preformatted_code: bool,
    pub translation_mode: TranslationMode,
}
The HTML to Markdown converting options.

Fields

heading_style: HeadingStylehr_style: HrStylebr_style: BrStylelink_style: LinkStylelink_reference_style: LinkReferenceStylecode_block_style: CodeBlockStylecode_block_fence: CodeBlockFencebullet_list_marker: BulletListMarkerul_bullet_spacing: u8

The number of spaces between the bullet character and the content.

ol_number_spacing: u8

The number of spaces between the period character and the content.

preformatted_code: bool

If true, the whitespace in inline <code> tags will be preserved.

translation_mode: TranslationMode